// $Id: MainPage.h 2148 2008-01-21 11:57:18Z mtjspaan $

// This file contains the text of the first page of the
// Doxygen-generated documentation. The file is called .h so doxygen
// will process it.

/**
\mainpage MultiAgentDecisionProcess documentation
 
\section intro Introduction

%MultiAgentDecisionProcess (MADP) is a toolbox for scientific research
in decision-theoretic planning and learning in multiagent systems.  It
is designed to be rather general, but most effort has been put in
planning algorithms for discrete Dec-POMDPs.

\section libs MADP Libraries

The framework consists of several parts, grouped in different
libraries. The base library (libMADPBase) contains:

\li A representation of the basic elements in a decision process such
as states, (joint) actions and observations. See State, StateDiscrete,
Action, ActionDiscrete, Observation, ObservationDiscrete, JointAction,
JointActionDiscrete, JointObservation, JointObservationDiscrete,
Agent.

\li A representation of the transition, observation and reward models
in a multiagent decision process. These models can also be stored in a
sparse fashion. See TransitionModelMapping,
TransitionModelMappingSparse, ObservationModelMapping,
ObservationModelMappingSparse, RewardModelMapping.

\li A uniform representation for MADP problems, which provides an
interface to a problem's model parameters. See
MultiAgentDecisionProcess, MultiAgentDecisionProcessDiscrete,
DecPOMDPDiscrete, POSGDiscrete.

\li Auxiliary functionality regarding manipulating indices, exception
handling and printing: E, IndexTools, PrintTools. Some project-wide
definitions are stored in the Globals namespace.

The parser library (libMADPParser) only requires the base library, and
contains:

\li A parser for \c dpomdp problem specifications, which is a
fileformat for discrete Dec-POMDPs. A set of benchmark problem files
can be found in the \c problems/ directory, and the \c dpomdp syntax
is documented in \link example.dpomdp \endlink. The format is based on
Tony's POMDP file format, and the formal specification is found in
dpomdp.spirit. The parser uses the Boost Spirit library. See
MADPParser.

The support library (libMADPSupport) contains basic data types useful
for planning:

\li A representation for (joint) histories, for storing and
manipulating observation, action and action-observation histories. See
ActionHistory, ObservationHistory, ActionObservationHistory,
JointActionHistory, JointObservationHistory,
JointActionObservationHistory.

\li A representation for (joint) beliefs, both stored as a full vector
as well as a sparse one. See JointBeliefInterface, JointBelief,
JointBeliefSparse.

\li Functionality for representing (joint) policies, as mappings from
histories to actions. See JointPolicyPureVector,
JointPolicyDiscretePure, JointPolicyDiscrete.

\li An implementation of the DecTiger problem which does not use \link
dectiger.dpomdp \endlink, see ProblemDecTiger.

\li Functionality for handling command-line arguments is provided by
ArgumentHandlers.

Finally, the planning library (libMADPplanning) contains functionality
for planning algorithms, as well as some solution methods.

\li Shared functionality for discrete MADP planning algorithms,
collect in PlanningUnitMADPDiscrete and
PlanningUnitDecPOMDPDiscrete. Computes (joint) history trees, joint
beliefs, and value functions.

\li Two Dec-POMDP solution algorithms: JESPExhaustivePlanner and
BruteForceSearchPlanner. They extend the planning units mentioned
before. They use ValueFunctionDecPOMDPDiscrete to compute the value of
a particular joint policy.

\li A simple simulator to empirically test the control quality of a
solution, see SimulationDecPOMDPDiscrete.

\section programs Programs using the MADP libraries

In the \c src/experiments/ and \c src/utils/ directories are a number
of programs included that use the MADP libraries. Running each binary
with as argument \c --help will display a short summary of usage.

\li \c JESP runs the JESPExhaustivePlanner on a \c dpomdp problem
specification, for instance 
\verbatim 
JESP -h 3 <PATH_TO>/dectiger.dpomdp
\endverbatim
runs JESP for horizon 3 on the DecTiger problem.

\li \c BFS runs the BruteForceSearchPlanner on a \c dpomdp file.

\li \c printProblem loads a \c dpomdp problem description and prints
it to standard out. \c printJointPolicyPureVector prints out a
particular joint policy given its index.

\li \c evaluateJointPolicyPureVector simulates a particular joint
policy for a problem. \c evaluateRandomPolicy uses a policy that
chooses actions uniformly at random.

\li \c analyzeRewardResults and \c getAvgReward
print information about the expected reward of simulation runs, saved
using SimulationResult::Save().

\section acks Acknowledgments

\htmlonly

The work reported here is part of the Interactive Collaborative
Information Systems (ICIS) <a
href="http://staff.science.uva.nl/~faolieho/index.php?fuseaction=phdproject.main">project</a>,
supported by the Dutch Ministry of Economic Affairs, grant nr: <a
href="http://www.icis.decis.nl">BSIK03024</a>.  This work was
partially supported by Funda&ccedil;&atilde;o para a Ci&ecirc;ncia e a
Tecnologia (ISR/IST pluriannual funding) through the POS_Conhecimento
Program that includes FEDER funds and through grant <a
href="http://www.isr.ist.utl.pt/~mtjspaan/decpucs">PTDC/EEA-ACR/73266/2006</a>.

\endhtmlonly

*/
