/**\file DecPOMDPDiscrete.cpp
 *
 * Authors:
 * Frans Oliehoek <faolieho@science.uva.nl>
 * Matthijs Spaan <mtjspaan@isr.ist.utl.pt>
 *
 * Copyright 2008 Universiteit van Amsterdam, Instituto Superior Tecnico
 *
 * This file is part of MultiAgentDecisionProcess.
 *
 * MultiAgentDecisionProcess is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * MultiAgentDecisionProcess is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MultiAgentDecisionProcess.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * $Id: DecPOMDPDiscrete.cpp 2151 2008-01-21 16:32:52Z mtjspaan $
 */

#include "DecPOMDPDiscrete.h"    

using namespace std;

#define DEBUG_DPOMDPD 0
//Debug Fill DecPOMDP Discrete - functions to initialize the DecPOMDPDiscrete
//(typically from a file)
#define DEBUG_FILLDPD 0

DecPOMDPDiscrete::DecPOMDPDiscrete(string name, string descr, string pf) :
    MultiAgentDecisionProcessDiscrete(name, descr, pf)
{
    _m_initialized = false;
    _m_p_rModel = 0;
}

DecPOMDPDiscrete::~DecPOMDPDiscrete()
{
    if(DEBUG_DPOMDPD)
        cout << "deleting DecPOMDPDiscrete (deleting rewards)"<<endl;
    delete(_m_p_rModel);
}

bool DecPOMDPDiscrete::SetInitialized(bool b)
{
    if( MultiAgentDecisionProcessDiscrete::SetInitialized(true) )
    {
        _m_initialized = b;
        return(true);
    }
    else
        return(false);
}

void DecPOMDPDiscrete::CreateNewRewardModel
    (size_t nrS, size_t nrJA)
{
    if(_m_initialized)
    delete(_m_p_rModel);

    _m_p_rModel = new RewardModelMapping( nrS, nrJA);
}

string DecPOMDPDiscrete::SoftPrint() const
{
    stringstream ss;
    ss << MultiAgentDecisionProcessDiscrete::SoftPrint();
    ss << DecPOMDP::SoftPrint();

    if(_m_initialized)
    {
        ss << "Reward model: " << endl;
        ss << _m_p_rModel->SoftPrint();
    }
    else
        throw E("DecPOMDPDiscrete components (reward model) not initialized");

    return(ss.str());
}


void DecPOMDPDiscrete::SetReward(Index sI, Index jaI, Index sucSI, double r)
{
    double rOld=GetReward(sI,jaI),
        rExp=GetTransitionProbability(sI,jaI,sucSI)*r;
    SetReward(sI,jaI,rOld+rExp);
}

void DecPOMDPDiscrete::SetReward(Index sI, Index jaI, Index sucSI,
                                 Index joI, double r)
{
    throw(E("DecPOMDPDiscrete::SetReward(sI,jaI,sucSI,joI,r) not implemented"));
}
