/**\file TransitionModelMappingSparse.h
 *
 * Authors:
 * Frans Oliehoek <faolieho@science.uva.nl>
 * Matthijs Spaan <mtjspaan@isr.ist.utl.pt>
 *
 * Copyright 2008 Universiteit van Amsterdam, Instituto Superior Tecnico
 *
 * This file is part of MultiAgentDecisionProcess.
 *
 * MultiAgentDecisionProcess is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * MultiAgentDecisionProcess is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MultiAgentDecisionProcess.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * $Id: TransitionModelMappingSparse.h 2151 2008-01-21 16:32:52Z mtjspaan $
 */

/* Only include this header file once. */
#ifndef _TRANSITIONMODELMAPPINGSPARSE_H_
#define _TRANSITIONMODELMAPPINGSPARSE_H_ 1

/* the include directives */
#include <boost/numeric/ublas/matrix_sparse.hpp>
#include "Globals.h"
#include "TransitionModelDiscrete.h"

/// TransitionModelMappingSparse implements a TransitionModelDiscrete.
/** Uses sparse matrices. */
class TransitionModelMappingSparse : public TransitionModelDiscrete
{
public:

#if BOOST_1_32_OR_LOWER // they renamed sparse_vector to mapped_vector
    typedef boost::numeric::ublas::sparse_matrix<double> SparseMatrix;
#else    
    typedef boost::numeric::ublas::mapped_matrix<double> SparseMatrix;
#endif    

private:
    
    std::vector<SparseMatrix* > _m_T;

protected:
    
public:
    // Constructor, destructor and copy assignment.
    /// default Constructor
    TransitionModelMappingSparse(int nrS = 1, int nrJA = 1);

    /// Copy constructor.
    TransitionModelMappingSparse(const TransitionModelMappingSparse& TM);

    /// Destructor.
    ~TransitionModelMappingSparse();    
        
    /// Returns P(s'|s,ja).
    double Get(Index sI, Index jaI, Index sucSI) const
        { return((*_m_T[jaI])(sI,sucSI)); }

    ////data manipulation funtions:
    /// Sets P(s'|s,ja) 
    /** sI, jaI, sucSI, are indices of the state, taken joint action
     * and resulting successor state. prob is the probability. The
     * order of events is s, ja, s', so is the arg. list
     */
    void Set(Index sI, Index jaI, Index sucSI, double prob)
        { (*_m_T[jaI])(sI,sucSI)=prob; }

    /// Get a pointer to a transition matrix for a particular action.
    const SparseMatrix* GetMatrixPtr(Index a) const
        { return(_m_T.at(a)); }

};

#endif /* !_TRANSITIONMODELMAPPINGSPARSE_H_ */


// Local Variables: ***
// mode:c++ ***
// End: ***
