/**\file JESP.cpp
 *
 * Authors:
 * Frans Oliehoek <faolieho@science.uva.nl>
 * Matthijs Spaan <mtjspaan@isr.ist.utl.pt>
 *
 * Copyright 2008 Universiteit van Amsterdam, Instituto Superior Tecnico
 *
 * This file is part of MultiAgentDecisionProcess.
 *
 * MultiAgentDecisionProcess is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * MultiAgentDecisionProcess is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MultiAgentDecisionProcess.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * $Id: JESP.cpp 2151 2008-01-21 16:32:52Z mtjspaan $
 */

#include "JESP.h"

using namespace std;

int main(int argc, char **argv)
{
    try {

    // parse the command-line arguments
    ArgumentHandlers::Arguments args;
    argp_parse (&ArgumentHandlers::theArgpStruc, argc, argv, 0, 0, &args);

    // construct a discrete DecPOMDP with the dpomdp problem filename
    DecPOMDPDiscrete decpomdp("","",args.dpf);
    if(args.sparse)
        decpomdp.SetSparse(true);
    // parse the .dpomdp file, which initializes the DecPOMDPDiscrete
    MADPParser parser(&decpomdp);

    // setup the parameters for planning unit, for JESP we want to
    // generate all the individual and joint histories, but there is
    // no need to store all joint beliefs
    PlanningUnitMADPDiscreteParameters params;
    params.SetComputeAll(true);
    params.SetComputeJointBeliefs(false);

    // initialize the JESP planner with the specified planning horizon 
    JESPExhaustivePlanner jesp(params,args.horizon,&decpomdp);

    cout << "JESPExhaustivePlanner initialized for horizon "
         << args.horizon << endl;

    // do the actual planning
    jesp.Plan();

    // print out the resulting value and policy
    cout << "Value = "<< jesp.GetExpectedReward() << endl;
    cout << jesp.GetJointPolicyPureVector()->SoftPrint() << endl;

    }
    catch(E& e){ e.Print(); }

    return(0);
}
