/**\file Belief.h
 *
 * Authors:
 * Frans Oliehoek <faolieho@science.uva.nl>
 * Matthijs Spaan <mtjspaan@isr.ist.utl.pt>
 *
 * Copyright 2008 Universiteit van Amsterdam, Instituto Superior Tecnico
 *
 * This file is part of MultiAgentDecisionProcess.
 *
 * MultiAgentDecisionProcess is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * MultiAgentDecisionProcess is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MultiAgentDecisionProcess.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * $Id: Belief.h 2151 2008-01-21 16:32:52Z mtjspaan $
 */

/* Only include this header file once. */
#ifndef _BELIEF_H_
#define _BELIEF_H_ 1

/* the include directives */
#include <iostream>
#include "Globals.h"
#include "BeliefInterface.h"

/// Belief represents a probability distribution over the state space.
/** It is stored as a full vector. */
class Belief : virtual public BeliefInterface
{
private:    
    
protected:
    
    /// The vector of probability values.
    std::vector<double> _m_b;

public:

    /// Constructor which sets the \a size of the belief.
    Belief(size_t size);

    /// Constructor which copies \a belief in this belief.
    Belief(const std::vector<double> &belief);

    /// Constructor which copies \a belief in this belief.
    Belief(const BeliefInterface &belief);

    /// Destructor.
    ~Belief();

    Belief& operator= (const Belief& o);
    BeliefInterface& operator= (const BeliefInterface& o);

    // operators:
    double& operator[] (Index& i) {
        return(_m_b[i]);
    }

    double& operator[] (int& i) {
        return(_m_b[i]);
    }

    //data manipulation (set) functions:

    void Set(const std::vector<double> &belief);

    void Set(Index sI, double prob) { _m_b[sI]=prob; }

    //get (data) functions:

    double Get(Index sI) const { return(_m_b.at(sI)); };

    std::vector<double> Get() const { return(_m_b); };

    void Clear();

    std::string SoftPrint() const;

    void Print() const { std::cout << SoftPrint(); }

    unsigned int Size() const { return(_m_b.size()); }

    bool SanityCheck() const;

    double InnerProduct(const std::vector<double> &values) const;

};


#endif /* !_BELIEF_H_ */

// Local Variables: ***
// mode:c++ ***
// End: ***
