/**\file JointPolicyDiscrete.cpp
 *
 * Authors:
 * Frans Oliehoek <faolieho@science.uva.nl>
 * Matthijs Spaan <mtjspaan@isr.ist.utl.pt>
 *
 * Copyright 2008 Universiteit van Amsterdam, Instituto Superior Tecnico
 *
 * This file is part of MultiAgentDecisionProcess.
 *
 * MultiAgentDecisionProcess is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * MultiAgentDecisionProcess is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MultiAgentDecisionProcess.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * $Id: JointPolicyDiscrete.cpp 2127 2008-01-18 14:06:16Z mtjspaan $
 */

#include "JointPolicyDiscrete.h"

//Default constructor
JointPolicyDiscrete::JointPolicyDiscrete(const 
        Interface_ProblemToPolicyDiscrete& iptpd,
        PolicyGlobals::IndexDomainCategory idc )
    :
        Referrer<Interface_ProblemToPolicyDiscrete>::Referrer(
                const_cast<Interface_ProblemToPolicyDiscrete&>(iptpd)
            )
{
    _m_indexDomCat = idc;
}
//Copy assignment constructor.    
JointPolicyDiscrete::JointPolicyDiscrete(const JointPolicyDiscrete& o) 
    :

        Referrer<Interface_ProblemToPolicyDiscrete>::Referrer(
                o.GetReferred()
            ),
        JointPolicy(o)
{
    _m_indexDomCat = o._m_indexDomCat;
}

JointPolicyDiscrete&
JointPolicyDiscrete::operator= (const JointPolicyDiscrete& o)
{
    if (this == &o) return *this;   // Gracefully handle self assignment
//    JointPolicy::operator= ( o );   //call parent
    _m_indexDomCat = o._m_indexDomCat;
    return *this;
}

Index JointPolicyDiscrete::SampleJointAction( Index i ) const
{
    size_t nrJA = GetInterfacePTPDiscrete()->GetNrJointActions();
    double randNr= ((double)rand()) / (RAND_MAX + 1.0);
    double sum=0;
    Index selected_ja=0;

    for(Index a=0; a<nrJA; a++)
    {
        sum+=GetJointActionProb(i, a);
        if(randNr<=sum)
        {
            selected_ja=a;
            break;
        }
    }
    return(selected_ja);
}
