/**\file argumentHandlers.h
 *
 * Authors:
 * Frans Oliehoek <faolieho@science.uva.nl>
 * Matthijs Spaan <mtjspaan@isr.ist.utl.pt>
 *
 * Copyright 2008 Universiteit van Amsterdam, Instituto Superior Tecnico
 *
 * This file is part of MultiAgentDecisionProcess.
 *
 * MultiAgentDecisionProcess is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * MultiAgentDecisionProcess is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MultiAgentDecisionProcess.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * $Id: argumentHandlers.h 2116 2008-01-16 23:11:49Z mtjspaan $
 */

#ifndef  _ARGUMENTHANDLERS_H_
#define  _ARGUMENTHANDLERS_H_ 1

#include <iostream>
#include <stdlib.h>
#include <error.h>
#include <argp.h>
#include "Globals.h"

/// \brief ArgumentHandlers contains functionality for parsing and
/// handling command-line arguments.
namespace ArgumentHandlers {

/// Arguments contains all defined parameters to be set on the command line. 
struct Arguments
{
    //General options (globopt)
    int quiet,verbose;    //quiet, verbose
    
    //The dec-pomdp file argument (dpf)
    char * dpf; //the dpomdp file string

    //model options (modelOptions)
    int sparse;

    //solution methods options (solutionMethodOptions)
    int horizon;

    //the jpolIndex input argument
    LIndex jpolIndex;

    // Simulation options
    int nrRuns;
    int randomSeed;

    //default values by constructor:
    Arguments()
    {
        // general
        quiet = 0;
        verbose = 0;
        // problem file
        dpf = 0;
        // model
        sparse = 0;
        // solution method
        horizon = 2;
        // jpol index
        jpolIndex = 0;
        // Simulation options
        nrRuns = 1000;
        randomSeed = 42;
    }
        
};


extern const char *argp_program_bug_address;

error_t problemFile_parse_argument (int key, char *arg,
                                    struct argp_state *state);
extern const struct argp_child problemFile_child;

error_t globalOptions_parse_argument (int key, char *arg,
                                      struct argp_state *state);
extern const struct argp_child globalOptions_child;

error_t modelOptions_parse_argument (int key, char *arg,
                                     struct argp_state *state);
extern const struct argp_child modelOptions_child;

error_t solutionMethodOptions_parse_argument (int key, char *arg,
                                              struct argp_state *state);
extern const struct argp_child solutionMethodOptions_child;

error_t jpolIndex_parse_argument (int key, char *arg, 
                                  struct argp_state *state);
extern const struct argp_child jpolIndex_child;

error_t simulation_parse_argument (int key, char *arg, 
                                   struct argp_state *state);
extern const struct argp_child simulation_child;

} //namespace

#endif /* !_ARGUMENTHANDLERS_H_*/
